# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class GoalInteractionsSummary(BaseModel):
    """
    GoalInteractionsSummary
    """ # noqa: E501
    is_available: Optional[StrictBool] = True
    last_engagement_at: Optional[StrictInt] = None
    last_opt_out_at: Optional[StrictInt] = None
    recent_interaction_count: Optional[StrictInt] = 0
    total_interaction_count: Optional[StrictInt] = 0
    __properties: ClassVar[List[str]] = ["is_available", "last_engagement_at", "last_opt_out_at", "recent_interaction_count", "total_interaction_count"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GoalInteractionsSummary from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GoalInteractionsSummary from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "is_available": obj.get("is_available") if obj.get("is_available") is not None else True,
            "last_engagement_at": obj.get("last_engagement_at"),
            "last_opt_out_at": obj.get("last_opt_out_at"),
            "recent_interaction_count": obj.get("recent_interaction_count") if obj.get("recent_interaction_count") is not None else 0,
            "total_interaction_count": obj.get("total_interaction_count") if obj.get("total_interaction_count") is not None else 0
        })
        return _obj





# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector_v2.models.usage_data_from_front_v2 import UsageDataFromFrontV2

class TestUsageDataFromFrontV2(unittest.TestCase):
    """UsageDataFromFrontV2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UsageDataFromFrontV2:
        """Test UsageDataFromFrontV2
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UsageDataFromFrontV2`
        """
        model = UsageDataFromFrontV2()
        if include_optional:
            return UsageDataFromFrontV2(
                chat_session_id = 56,
                usage_data = [
                    chat_server_connector_v2.models.usage_data_v2.UsageDataV2(
                        type = 'text', 
                        price_usd = 1.337, 
                        model = '', )
                    ]
            )
        else:
            return UsageDataFromFrontV2(
                chat_session_id = 56,
                usage_data = [
                    chat_server_connector_v2.models.usage_data_v2.UsageDataV2(
                        type = 'text', 
                        price_usd = 1.337, 
                        model = '', )
                    ],
        )
        """

    def testUsageDataFromFrontV2(self):
        """Test UsageDataFromFrontV2"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
